diff --git a/tools/ConfigDb/load_ConfigDb.sh b/tools/ConfigDb/load_ConfigDb.sh
index 353d4b01486e4464fe8374d34ebfe35d430e7564..cc7123223ac4303c457f2b0a9fcae5b5b4157c2d 100755
--- a/tools/ConfigDb/load_ConfigDb.sh
+++ b/tools/ConfigDb/load_ConfigDb.sh
@@ -1,9 +1,9 @@
 if [ ${#} -ne 1 ]; then
     echo "You must provide a file name for the TANGO_HOST DB dump!"
     exit -1
-# Check if the filename begins with /hosthome/, /opt/tango or /opt/lofar:
-elif [ ${1:0:10} != /hosthome/ -a ${1:0:11} != /opt/tango/ -a ${1:0:11} != /opt/lofar/ ]; then
-    echo "You must provide a full file path that begins with one of \"/hosthome/\", \"/opt/tango/\" or \"/opt/lofar/\".  Why is that?  Because the file will be loaded from within the Docker container and only some of the host's file system directories are mounted in the container."
+# Check if the filename begins with /hosthome/, /opt/lofar2.0/tango or /opt/lofar2.0/:
+elif [ ${1:0:10} != /hosthome/ -a ${1:0:20} != /opt/lofar2.0/tango/ -a ${1:0:14} != /opt/lofar2.0/ ]; then
+    echo "You must provide a full file path that begins with one of \"/hosthome/\", \"/opt/lofar2.0/tango/\" or \"/opt/lofar2.0/\".  Why is that?  Because the file will be loaded from within the Docker container and only some of the host's file system directories are mounted in the container."
     exit -2
 fi
 
diff --git a/tools/ConfigDb/update_ConfigDb.sh b/tools/ConfigDb/update_ConfigDb.sh
index 277e92f560a5a58ce12b79b2ab23de0ef961c4e2..003ddd7eacb65d3916c3658b710b36e874f83a51 100755
--- a/tools/ConfigDb/update_ConfigDb.sh
+++ b/tools/ConfigDb/update_ConfigDb.sh
@@ -1,9 +1,9 @@
 if [ ${#} -ne 1 ]; then
     echo "You must provide a file name for the TANGO_HOST DB dump!"
     exit -1
-# Check if the filename begins with /hosthome/, /opt/tango or /opt/lofar:
-elif [ ${1:0:10} != /hosthome/ -a ${1:0:11} != /opt/tango/ -a ${1:0:11} != /opt/lofar/ ]; then
-    echo "You must provide a full file path that begins with one of \"/hosthome/\", \"/opt/tango/\" or \"/opt/lofar/\".  Why is that?  Because the file will be loaded from within the Docker container and only some of the host's file system directories are mounted in the container."
+# Check if the filename begins with /hosthome/, /opt/lofar2.0/tango or /opt/lofar2.0/:
+elif [ ${1:0:10} != /hosthome/ -a ${1:0:20} != /opt/lofar2.0/tango/ -a ${1:0:14} != /opt/lofar2.0/ ]; then
+    echo "You must provide a full file path that begins with one of \"/hosthome/\", \"/opt/lofar2.0/tango/\" or \"/opt/lofar2.0/\".  Why is that?  Because the file will be loaded from within the Docker container and only some of the host's file system directories are mounted in the container."
     exit -2
 fi